@@ -32,14 +32,14 @@ string face_cascade_path, eye_cascade_path, nose_cascade_path, mouth_cascade_pat
 int main(int argc, char** argv)
 {
     cv::CommandLineParser parser(argc, argv,
-            "{eyes||}{nose||}{mouth||}{help h||}");
+            "{eyes||}{nose||}{mouth||}{help h||}{@image||}{@facexml||}");
     if (parser.has("help"))
     {
         help();
         return 0;
     }
-    input_image_path = parser.get<string>(0);
-    face_cascade_path = parser.get<string>(1);
+    input_image_path = parser.get<string>("@image");
+    face_cascade_path = parser.get<string>("@facexml");
     eye_cascade_path = parser.has("eyes") ? parser.get<string>("eyes") : "";
     nose_cascade_path = parser.has("nose") ? parser.get<string>("nose") : "";
     mouth_cascade_path = parser.has("mouth") ? parser.get<string>("mouth") : "";
@@ -50,7 +50,7 @@ int main(int argc, char** argv)
     }
     // Load image and cascade classifier files
     Mat image;
-    image = imread(input_image_path);
+    image = imread(samples::findFile(input_image_path));
 
     // Detect faces and facial features
     vector<Rect_<int> > faces;
@@ -89,7 +89,7 @@ static void help()
         "\tThis will detect only the face in image.jpg.\n";
 
     cout << " \n\nThe classifiers for face and eyes can be downloaded from : "
-        " \nhttps://github.com/opencv/opencv/tree/3.4/data/haarcascades";
+        " \nhttps://github.com/opencv/opencv/tree/master/data/haarcascades";
 
     cout << "\n\nThe classifiers for nose and mouth can be downloaded from : "
         " \nhttps://github.com/opencv/opencv_contrib/tree/master/modules/face/data/cascades\n";
@@ -98,9 +98,10 @@ static void help()
 static void detectFaces(Mat& img, vector<Rect_<int> >& faces, string cascade_path)
 {
     CascadeClassifier face_cascade;
-    face_cascade.load(cascade_path);
+    face_cascade.load(samples::findFile(cascade_path));
 
-    face_cascade.detectMultiScale(img, faces, 1.15, 3, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
+    if (!face_cascade.empty())
+        face_cascade.detectMultiScale(img, faces, 1.15, 3, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
     return;
 }
 
@@ -186,26 +187,29 @@ static void detectFacialFeaures(Mat& img, const vector<Rect_<int> > faces, strin
 static void detectEyes(Mat& img, vector<Rect_<int> >& eyes, string cascade_path)
 {
     CascadeClassifier eyes_cascade;
-    eyes_cascade.load(cascade_path);
+    eyes_cascade.load(samples::findFile(cascade_path, !cascade_path.empty()));
 
-    eyes_cascade.detectMultiScale(img, eyes, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
+    if (!eyes_cascade.empty())
+        eyes_cascade.detectMultiScale(img, eyes, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
     return;
 }
 
 static void detectNose(Mat& img, vector<Rect_<int> >& nose, string cascade_path)
 {
     CascadeClassifier nose_cascade;
-    nose_cascade.load(cascade_path);
+    nose_cascade.load(samples::findFile(cascade_path, !cascade_path.empty()));
 
-    nose_cascade.detectMultiScale(img, nose, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
+    if (!nose_cascade.empty())
+        nose_cascade.detectMultiScale(img, nose, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
     return;
 }
 
 static void detectMouth(Mat& img, vector<Rect_<int> >& mouth, string cascade_path)
 {
     CascadeClassifier mouth_cascade;
-    mouth_cascade.load(cascade_path);
+    mouth_cascade.load(samples::findFile(cascade_path, !cascade_path.empty()));
 
-    mouth_cascade.detectMultiScale(img, mouth, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
+    if (!mouth_cascade.empty())
+        mouth_cascade.detectMultiScale(img, mouth, 1.20, 5, 0|CASCADE_SCALE_IMAGE, Size(30, 30));
     return;
 }
